Crate hyper_client_pool

Crate hyper_client_pool 

Re-exports

pub extern crate hyper;

Structs

Config
Configuration for [pool::Pool].
DefaultConnectorAdapator
Default type that implemented ConnectorAdaptor, just passes through the connector
Error
An error returned when requesting a Transaction.
Pool
A pool of hyper::Clients.
PoolBuilder
Transaction
A container type for a hyper::Request as well as the deliverable which receives the result of the request.
TransactionCounter

Enums

DeliveryResult
The result of the transaction, a message sent to the deliverable.
ErrorKind
Types of errors that can occur when requesting. A SpawnError can occur when requesting a Transaction as a new thread may need spawned if a previous one was lost / invalidated.
SpawnError
Error when spawning and configuring the thread that the hyper::Clients run on.

Traits

ConnectorAdaptor
A trait used to wrap the PoolConnector used by default into a different type that implements Connect
CreateResolver
A trait used to create a DNS resolver. DefaultResolver uses the default DNS resolver built into hyper.
Deliverable
The trait that handles the completion of the transaction (DeliveryResult). complete() is guaranteed to be called once the Transaction is spawned, even if the thread panics or the future is dropped.

Type Aliases

PoolConnector