pub enum ErrorKind {
Spawn(SpawnError),
PoolFull,
}Expand description
Types of errors that can occur when requesting.
A SpawnError can occur when requesting a Transaction as a new thread may need
spawned if a previous one was lost / invalidated.
Variants
Spawn(SpawnError)
An error occurred when spawning and configuring a new thread for a hyper::Client
PoolFull
There is no room for another transaction right now, the pool is full.