Pool

Struct Pool 

pub struct Pool<D: Deliverable> { /* private fields */ }
A pool of hyper::Clients.

Manages a set of hyper::Client for maximizing throughput while presenting a request API similar to using a hyper::Client directly. The number of active transactions running on each client is tracked so that max_transactions_per_worker is respected. When all clients are full, backpressure is provided in the form of an Error variant saying “busy; try again later”.

Implementations

Source

impl<D: Deliverable> Pool<D>

pub fn builder(config: Config) -> PoolBuilder<D>

pub fn request(&mut self, transaction: Transaction<D>) -> Result<(), Error<D>>

Start or queue a request

The request will be started immediately assuming one of the clients in this pool is not at max_sockets.

pub async fn shutdown(self)

Shutdown the pool

Waits for all workers to be empty before stopping.