pub enum DeliveryResult {
Dropped,
Response {
response: Response<Body>,
body: Option<Vec<u8>>,
body_size: usize,
duration: Duration,
},
Timeout {
duration: Duration,
},
HyperError {
error: Error,
duration: Duration,
},
}Expand description
The result of the transaction, a message sent to the deliverable.
This must be sent to the deliverable in any case in order to prevent data loss.
Variants
Dropped
The delivery was dropped, unknown if it was sent or not.
Response
Received a response from the external server.
Timeout
Failed to connect within the timeout limit.
HyperError
Sending a request through hyper encountered an error.