pub struct Pool<D: Deliverable> { /* private fields */ }Expand description
A pool of hyper::Clients.
Manages a set of hyper::Client for maximizing throughput while presenting
a request API similar to using a hyper::Client directly. The number of
active transactions running on each client is tracked so that max_transactions_per_worker
is respected. When all clients are full, backpressure is provided in the
form of an Error variant saying “busy; try again later”.
Implementations
Sourceimpl<D: Deliverable> Pool<D>
impl<D: Deliverable> Pool<D>
pub fn builder(config: Config) -> PoolBuilder<D>