pub struct Transaction<D: Deliverable> { /* private fields */ }Expand description
A container type for a hyper::Request as well as the deliverable
which receives the result of the request.
Implementations
Sourceimpl<D: Deliverable> Transaction<D>
impl<D: Deliverable> Transaction<D>
pub fn new( deliverable: D, request: Request<Body>, requires_body: bool, ) -> Transaction<D>
Sourcepub fn with_parent_span(self, span_id: impl Into<Option<Id>>) -> Self
pub fn with_parent_span(self, span_id: impl Into<Option<Id>>) -> Self
Report tracing events for this transaction within the tracing::Span
with the provided ID. Most interesting of these events is the
debug-level http_request span, which tries to have fields provided in
the opentelemetry HTTP conventions document. This event will be reported
wether this method is called or not, but it will be much more useful if
you provide a parent span so that you can determine why the request is
being made.
https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/semantic_conventions/http.md